@@ -78,12 +78,14 @@ var MyApplication = GObject.registerClass({
         ]);
         this.set_accels_for_action('app.quit', ['<Primary>q']);
         this.set_accels_for_action('win.find', ['<Primary>f']);
-        this.set_accels_for_action('win.show-primary-menu', ['F10']);
         this.set_accels_for_action('win.show-help-overlay', ['<Primary>question']);
 
         settings = Util.getSettings('org.gnome.Characters',
             '/org/gnome/Characters/');
 
+        if (this.get_flags() & Gio.ApplicationFlags.IS_SERVICE)
+            this.set_inactivity_timeout(10000);
+
         log('Characters Application started');
     }
 
