@@ -23,7 +23,7 @@ const { Gc, Gio, GLib, GObject } = imports.gi;
 const ByteArray = imports.byteArray;
 const Util = imports.util;
 
-const MAX_SEARCH_RESULTS = 100;
+const MAX_SEARCH_RESULTS = 20;
 
 const SearchProviderInterface = ByteArray.toString(Gio.resources_lookup_data('/org/gnome/shell/ShellSearchProvider2.xml', 0).toArray());
 
@@ -46,6 +46,7 @@ var SearchProvider = GObject.registerClass({
     }
 
     _runQuery(keywords, invocation) {
+        this._app.hold();
         this._cancellable.cancel();
         this._cancellable.reset();
 
@@ -65,6 +66,7 @@ var SearchProvider = GObject.registerClass({
                     log(`Failed to search by keywords: ${e.message}`);
                 }
                 invocation.return_value(new GLib.Variant('(as)', [characters]));
+                this._app.release();
             });
     }
 
@@ -77,6 +79,7 @@ var SearchProvider = GObject.registerClass({
     }
 
     GetResultMetas(identifiers) {
+        this._app.hold();
         let ret = [];
 
         for (let i = 0; i < identifiers.length; i++) {
@@ -96,6 +99,9 @@ var SearchProvider = GObject.registerClass({
             }
 
             let iconData = Util.characterToIconData(character);
+            if (!iconData)
+                continue;
+
             ret.push({
                 name: new GLib.Variant('s', name),
                 id: new GLib.Variant('s', identifiers[i]),
@@ -104,6 +110,7 @@ var SearchProvider = GObject.registerClass({
                 'icon-data': iconData,
             });
         }
+        this._app.release();
         return ret;
     }
 
