@@ -34,9 +34,9 @@ const Util = imports.util;
 var MainWindow = GObject.registerClass({
     Template: 'resource:///org/gnome/Characters/window.ui',
     InternalChildren: [
-        'searchButton', 'search-bar', 'searchEntry', 'back-button',
+        'searchButton', 'search-bar', 'searchEntry',
         'container', 'sidebar', 'loadingSpinner',
-        'leaflet', 'mainStack', 'windowTitle',
+        'splitView', 'mainStack', 'contentChild',
         'charactersView', 'scrolledWindow', 'primaryMenuButton',
     ],
     Properties: {
@@ -64,14 +64,14 @@ var MainWindow = GObject.registerClass({
             if (row) {
                 this._sidebar.lastSelectedRow = row;
                 this.setPage(row);
-                this._windowTitle.title = row.title;
-                this._leaflet.navigate(Adw.NavigationDirection.FORWARD);
+                this._contentChild.title = row.title;
+                this._splitView.show_content = true;
             }
         });
 
         // FIXME: Can't use GSettings.bind with 'as' from Gjs
         let recentCharacters = Main.settings.get_value('recent-characters');
-        this.recentCharacters = recentCharacters.get_strv();
+        this.recentCharacters = recentCharacters.deepUnpack();
         this._maxRecentCharacters = 100;
         Main.settings.bind('max-recent-characters', this,
             'max-recent-characters',
@@ -85,7 +85,6 @@ var MainWindow = GObject.registerClass({
                     this._searchButton.active = !this._searchButton.active;
                 },
             },
-            { name: 'show-primary-menu', activate: this._showPrimaryMenu },
         ]);
 
         this._searchButton.bind_property('active',
@@ -114,10 +113,8 @@ var MainWindow = GObject.registerClass({
             this._searchButton.set_active(false);
         });
 
-        this._back_button.connect('clicked', () => {
-            this._leaflet.navigate(Adw.NavigationDirection.BACK);
-            if (this._leaflet.get_folded())
-                this._sidebar.unselectAll();
+        this._contentChild.connect('hiding', () => {
+            this._sidebar.unselectAll();
         });
 
         this._charactersView.connect('notify::loading', view => {
@@ -141,15 +138,10 @@ var MainWindow = GObject.registerClass({
             this._sidebar.selectRowByName('smileys');
     }
 
-    _showPrimaryMenu() {
-        const popover = this._primaryMenuButton.get_popover();
-        popover.popup();
-    }
-
     set searchActive(v) {
         if (v) {
             this._sidebar.unselectAll();
-            this._windowTitle.title = _('Search Result');
+            this._contentChild.title = _('Search Result');
         } else {
             this._sidebar.restoreSelection();
         }
